@@ -161,7 +161,6 @@ class Builder(object):
         # Find how we'll map source to destination filenames.
         mapping = self._get_directory_mapping(abs_original, source_path, files)
 
-
         # Recurse through each of its contents.
         for source, target in mapping.items():
             abs_path = os.path.join(abs_original, source)
@@ -271,7 +270,7 @@ class Builder(object):
         """Checks to see if this path matches any of the regular
         expressions we're ignoring."""
 
-        ignores = self._ignore_filenames
+        ignores = self._ignore_filenames[:]
         for config in self._extra_config:
             ignores.extend(config.get('ignore', []))
 
@@ -281,7 +280,7 @@ class Builder(object):
         """Checks to see if this path is one of those we shouldn't run
         through the tempating system."""
 
-        verbatims = self._verbatim_filenames
+        verbatims = self._verbatim_filenames[:]
         for config in self._extra_config:
             verbatims.extend(config.get('verbatim', []))
 
